diff --git a/chrome/content/scaffold/scaffold.xhtml b/chrome/content/scaffold/scaffold.xhtml
index e2b8ae08c0..e86c67a2a2 100644
--- a/chrome/content/scaffold/scaffold.xhtml
+++ b/chrome/content/scaffold/scaffold.xhtml
@@ -97,7 +97,7 @@
-
+
diff --git a/chrome/content/scaffold/scaffold.js b/chrome/content/scaffold/scaffold.js
index 74ac6ad0a5..94990fd3c6 100644
--- a/chrome/content/scaffold/scaffold.js
+++ b/chrome/content/scaffold/scaffold.js
@@ -596,8 +596,8 @@ var Scaffold = new function () {
_editors.code.updateOptions({ fontSize: size + 1 });
_editors.tests.updateOptions({ fontSize: size + 1 });
document.getElementById("scaffold-pane").style.fontSize = sizeWithPX;
- if (size == 11) {
- // for the default value 11, clear the prefs
+ if (size == 13) {
+ // for the default value 13, clear the prefs
Zotero.Prefs.clear('scaffold.fontSize');
}
else {
@@ -606,11 +606,11 @@ var Scaffold = new function () {
};
this.increaseFontSize = function () {
- var currentSize = Zotero.Prefs.get("scaffold.fontSize") || 11;
+ var currentSize = Zotero.Prefs.get("scaffold.fontSize") || 13;
this.setFontSize(currentSize + 2);
};
this.decreaseFontSize = function () {
- var currentSize = Zotero.Prefs.get("scaffold.fontSize") || 11;
+ var currentSize = Zotero.Prefs.get("scaffold.fontSize") || 13;
this.setFontSize(currentSize - 2);
};